==> gnome_terminal-2.26.2-i586-P1.tgz: install/doinst.sh <==
( cd usr/share/gnome/help/gnome-terminal/da/figures ; rm -rf gnome-terminal-default.png )
( cd usr/share/gnome/help/gnome-terminal/da/figures ; ln -sf ../../C/figures/gnome-terminal-default.png gnome-terminal-default.png )
( cd usr/share/gnome/help/gnome-terminal/da/figures ; rm -rf gnome-terminal-tabbed.png )
( cd usr/share/gnome/help/gnome-terminal/da/figures ; ln -sf ../../C/figures/gnome-terminal-tabbed.png gnome-terminal-tabbed.png )
( cd usr/share/gnome/help/gnome-terminal/cs/figures ; rm -rf gnome-terminal-default.png )
( cd usr/share/gnome/help/gnome-terminal/cs/figures ; ln -sf ../../C/figures/gnome-terminal-default.png gnome-terminal-default.png )
( cd usr/share/gnome/help/gnome-terminal/cs/figures ; rm -rf gnome-terminal-tabbed.png )
( cd usr/share/gnome/help/gnome-terminal/cs/figures ; ln -sf ../../C/figures/gnome-terminal-tabbed.png gnome-terminal-tabbed.png )
( cd usr/share/gnome/help/gnome-terminal/oc/figures ; rm -rf gnome-terminal-default.png )
( cd usr/share/gnome/help/gnome-terminal/oc/figures ; ln -sf ../../C/figures/gnome-terminal-default.png gnome-terminal-default.png )
( cd usr/share/gnome/help/gnome-terminal/oc/figures ; rm -rf gnome-terminal-tabbed.png )
( cd usr/share/gnome/help/gnome-terminal/oc/figures ; ln -sf ../../C/figures/gnome-terminal-tabbed.png gnome-terminal-tabbed.png )
( cd usr/share/gnome/help/gnome-terminal/ru/figures ; rm -rf gnome-terminal-default.png )
( cd usr/share/gnome/help/gnome-terminal/ru/figures ; ln -sf ../../C/figures/gnome-terminal-default.png gnome-terminal-default.png )
( cd usr/share/gnome/help/gnome-terminal/ru/figures ; rm -rf gnome-terminal-tabbed.png )
( cd usr/share/gnome/help/gnome-terminal/ru/figures ; ln -sf ../../C/figures/gnome-terminal-tabbed.png gnome-terminal-tabbed.png )
( cd usr/share/gnome/help/gnome-terminal/en_GB/figures ; rm -rf gnome-terminal-default.png )
( cd usr/share/gnome/help/gnome-terminal/en_GB/figures ; ln -sf ../../C/figures/gnome-terminal-default.png gnome-terminal-default.png )
( cd usr/share/gnome/help/gnome-terminal/en_GB/figures ; rm -rf gnome-terminal-tabbed.png )
( cd usr/share/gnome/help/gnome-terminal/en_GB/figures ; ln -sf ../../C/figures/gnome-terminal-tabbed.png gnome-terminal-tabbed.png )
#%% begin initialize gnome_terminal-2.26.2-i586-P1
if [ -x /usr/bin/scrollkeeper-update ]; then
    scrollkeeper-update -p /var/lib/rarian -o /usr/share/omf/gnome-terminal
fi
if [ -x /usr/bin/scrollkeeper-update ]; then
    scrollkeeper-update -p /var/lib/rarian -o /usr/share/omf/help
fi
if [ -x /usr/bin/gconftool-2 ]; then
    ( cd /etc/gconf/schemas ; GCONF_CONFIG_SOURCE=xml:merged:/etc/gconf/gconf.xml.defaults /usr/bin/gconftool-2 --makefile-install-rule gnome-terminal.schemas )
fi
#%% end

==> gnome_terminal-2.26.3.1-i586-P1.tgz: install/doinst.sh <==
( cd usr/share/gnome/help/gnome-terminal/da/figures ; rm -rf gnome-terminal-default.png )
( cd usr/share/gnome/help/gnome-terminal/da/figures ; ln -sf ../../C/figures/gnome-terminal-default.png gnome-terminal-default.png )
( cd usr/share/gnome/help/gnome-terminal/da/figures ; rm -rf gnome-terminal-tabbed.png )
( cd usr/share/gnome/help/gnome-terminal/da/figures ; ln -sf ../../C/figures/gnome-terminal-tabbed.png gnome-terminal-tabbed.png )
( cd usr/share/gnome/help/gnome-terminal/cs/figures ; rm -rf gnome-terminal-default.png )
( cd usr/share/gnome/help/gnome-terminal/cs/figures ; ln -sf ../../C/figures/gnome-terminal-default.png gnome-terminal-default.png )
( cd usr/share/gnome/help/gnome-terminal/cs/figures ; rm -rf gnome-terminal-tabbed.png )
( cd usr/share/gnome/help/gnome-terminal/cs/figures ; ln -sf ../../C/figures/gnome-terminal-tabbed.png gnome-terminal-tabbed.png )
( cd usr/share/gnome/help/gnome-terminal/en_GB/figures ; rm -rf gnome-terminal-default.png )
( cd usr/share/gnome/help/gnome-terminal/en_GB/figures ; ln -sf ../../C/figures/gnome-terminal-default.png gnome-terminal-default.png )
( cd usr/share/gnome/help/gnome-terminal/en_GB/figures ; rm -rf gnome-terminal-tabbed.png )
( cd usr/share/gnome/help/gnome-terminal/en_GB/figures ; ln -sf ../../C/figures/gnome-terminal-tabbed.png gnome-terminal-tabbed.png )
( cd usr/share/gnome/help/gnome-terminal/oc/figures ; rm -rf gnome-terminal-default.png )
( cd usr/share/gnome/help/gnome-terminal/oc/figures ; ln -sf ../../C/figures/gnome-terminal-default.png gnome-terminal-default.png )
( cd usr/share/gnome/help/gnome-terminal/oc/figures ; rm -rf gnome-terminal-tabbed.png )
( cd usr/share/gnome/help/gnome-terminal/oc/figures ; ln -sf ../../C/figures/gnome-terminal-tabbed.png gnome-terminal-tabbed.png )
( cd usr/share/gnome/help/gnome-terminal/ru/figures ; rm -rf gnome-terminal-default.png )
( cd usr/share/gnome/help/gnome-terminal/ru/figures ; ln -sf ../../C/figures/gnome-terminal-default.png gnome-terminal-default.png )
( cd usr/share/gnome/help/gnome-terminal/ru/figures ; rm -rf gnome-terminal-tabbed.png )
( cd usr/share/gnome/help/gnome-terminal/ru/figures ; ln -sf ../../C/figures/gnome-terminal-tabbed.png gnome-terminal-tabbed.png )
#%% begin initialize gnome_terminal-2.26.3.1-i586-P1
if [ -x /usr/bin/scrollkeeper-update ]; then
    scrollkeeper-update -p /var/lib/rarian -o /usr/share/omf/gnome-terminal
fi
if [ -x /usr/bin/gconftool-2 ]; then
    ( cd /etc/gconf/schemas ; GCONF_CONFIG_SOURCE=xml:merged:/etc/gconf/gconf.xml.defaults /usr/bin/gconftool-2 --makefile-install-rule gnome-terminal.schemas )
fi
#%% end
